Notification Email Module
#########################

The notification email module allows to define email templates which will be
sent to a list of recipients when a trigger is fired on a record event.
Extra reports from the same record can be attached to the email.
